@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2010-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -16,7 +16,7 @@
  *
  * @author    Michael J. Rubinsky <mrubinsk@horde.org>
  * @category  Horde
- * @copyright 2010-2016 Horde LLC
+ * @copyright 2010-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL-2.1
  * @package   Image
  */
@@ -44,13 +44,15 @@ class Horde_Image_Effect_Im_LiquidResize extends Horde_Image_Effect
 
         $this->_image->addOperation("-size {$resWidth}x{$resHeight}");
         if ($this->_params->get('ratio', true)) {
-            $this->_image->addPostSrcOperation(
-                "-liquid-rescale {$this->_params->width}x{$this->_params->height}"
-            );
+            $this->_image->addPostSrcOperation(sprintf(
+                '-liquid-rescale %dx%d',
+                $this->_params->width, $this->_params->height
+            ));
         } else {
-            $this->_image->addPostSrcOperation(
-                "-liquid-rescale {$this->_params->width}x{$this->_params->height}!"
-            );
+            $this->_image->addPostSrcOperation(sprintf(
+                '-liquid-rescale %dx%d!',
+                $this->_params->width, $this->_params->height
+            ));
         }
         $this->_image->clearGeometry();
     }
