@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2007-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2007-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -16,7 +16,7 @@
  *
  * @author    Michael J. Rubinsky <mrubinsk@horde.org>
  * @category  Horde
- * @copyright 2007-2016 Horde LLC
+ * @copyright 2007-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL-2.1
  * @package   Image
  */
@@ -46,18 +46,18 @@ class Horde_Image_Effect_Im_PolaroidImage extends Horde_Image_Effect
         $ver = $this->_image->getIMVersion();
         if (is_array($ver) && version_compare($ver[0], '6.3.2') >= 0) {
             $this->_image->addPostSrcOperation(sprintf(
-                "-bordercolor \"#eee\" -background none -polaroid %s \( +clone -fill %s -draw 'color 0,0 reset' \) +swap +flatten",
+                '-bordercolor "#eee" -background none -polaroid %d \( +clone -fill %s -draw \'color 0,0 reset\' \) +swap +flatten',
                 $this->_params['angle'],
-                $this->_params['background']
+                escapeshellarg($this->_params['background'])
             ));
         } else {
             $size = $this->_image->getDimensions();
             $this->_image->addPostSrcOperation(sprintf(
-                "-bordercolor \"#eee\" -border 8 -bordercolor grey90 -border 1 -bordercolor none -background none -rotate %s \( +clone -shadow 60x1.5+1+1 -rotate 90 -wave 1x%s -rotate 90 \) +swap -rotate 90 -wave 1x%s -rotate -90 -flatten \( +clone -fill %s -draw 'color 0,0 reset ' \) +swap -flatten",
+                '-bordercolor \"#eee\" -border 8 -bordercolor grey90 -border 1 -bordercolor none -background none -rotate %d \( +clone -shadow 60x1.5+1+1 -rotate 90 -wave 1x%s -rotate 90 \) +swap -rotate 90 -wave 1x%s -rotate -90 -flatten \( +clone -fill %s -draw \'color 0,0 reset \' \) +swap -flatten',
                 $this->_params['angle'],
                 $size['height'] * 2,
                 $size['height'] * 2,
-                $this->_params['background']
+                escapeshellarg($this->_params['background'])
             ));
         }
     }
