@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2007-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2007-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -16,7 +16,7 @@
  *
  * @author    Michael J. Rubinsky <mrubinsk@horde.org>
  * @category  Horde
- * @copyright 2007-2016 Horde LLC
+ * @copyright 2007-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL-2.1
  * @package   Image
  */
@@ -83,7 +83,7 @@ class Horde_Image_Effect_Im_TextWatermark extends Horde_Image_Effect
         $this->_image->addPostSrcOperation(
             ' -font ' . $this->_params['font'] . ' -pointsize ' . $point
             . ' \( +clone -resize 1x1 -fx 1-intensity -threshold 50% -scale 32x32 -write mpr:color +delete \) -tile mpr:color -gravity '
-            . $gravity . ' -annotate +20+10 "' . $this->_params['text'] . '"'
+            . $gravity . ' -annotate +20+10 "' . escapeshellarg($this->_params['text']) . '"'
         );
         $this->_image->raw();
     }
