@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2010-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -16,7 +16,7 @@
  *
  * @author    Michael J. Rubinsky <mrubinsk@horde.org>
  * @category  Horde
- * @copyright 2010-2016 Horde LLC
+ * @copyright 2010-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL-2.1
  * @package   Image
  */
@@ -59,8 +59,9 @@ class Horde_Image_Effect_Im_Unsharpmask extends Horde_Image_Effect
             ? $this->_params['radius']
             : sqrt($this->_params['radius']);
 
-        $this->_image->addPostSrcOperation(
-            "-unsharp {$this->_params['radius']}x{$this->_params['sigma']}+{$this->_params['amount']}+{$this->_params['threshold']}"
-        );
+        $this->_image->addPostSrcOperation(sprintf(
+            '-unsharp %Fx%F+%F+%F',
+            $this->_params['radius'], $this->_params['sigma'], $this->_params['amount'], $this->_params['threshold']
+        ));
     }
 }
