@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2007-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2007-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -19,7 +19,7 @@
  *
  * @author    Michael J. Rubinsky <mrubinsk@horde.org>
  * @category  Horde
- * @copyright 2007-2016 Horde LLC
+ * @copyright 2007-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL-2.1
  * @package   Image
  */
@@ -110,7 +110,7 @@ class Horde_Image_Effect_Imagick_PhotoStack extends Horde_Image_Effect
                         );
                     } else {
                         $imgk->destroy();
-                        $imgk = $topimg->clone();
+                        $imgk = $this->_image->cloneImagickObject($topimg);
                     }
                     if ($this->_params['type'] == 'rounded') {
                         $imgk = $this->_roundBorder($imgk);
@@ -123,7 +123,7 @@ class Horde_Image_Effect_Imagick_PhotoStack extends Horde_Image_Effect
                     }
                     // Only shadow the bottom image for 'plain' stacks
                     if (!$haveBottom) {
-                        $shad = $imgk->clone();
+                        $shad = $this->_image->cloneImagickObject($imgk);
                         $shad->setImageBackgroundColor(
                             new ImagickPixel('black')
                         );
@@ -170,7 +170,7 @@ class Horde_Image_Effect_Imagick_PhotoStack extends Horde_Image_Effect
                         }
                     }
                     $result = $imgk->polaroidImage(new ImagickDraw(), $angle);
-   
+
                     // Get the geometry of the image and remember the largest.
                     $geo = $imgk->getImageGeometry();
                     $length = max(
