@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2015-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2015-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -17,7 +17,7 @@
  *
  * @author    Jan Schneider <jan@horde.org>
  * @category  Horde
- * @copyright 2015-2016 Horde LLC
+ * @copyright 2015-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL-2.1
  * @package   Image
  */
@@ -32,6 +32,8 @@ class Horde_Image_Null extends Horde_Image_Base
             $this->loadFile($params['filename']);
         } elseif (!empty($params['data'])) {
             $this->loadString($params['data']);
+        } else {
+           $this->_data = new Horde_Stream_Temp();
         }
     }
 }
